<?php
/**
 * PHP wrapper for Google web APIs 
 * 
 * hacked by Raj Shekhar
 *
 * ** Start legal things **
 * 
 * This work, including the source code, documentation and related
 * data, is placed into the public domain.
 *
 * The orginal author is Raj Shekhar
 *
 * THIS SOFTWARE IS PROVIDED AS-IS WITHOUT WARRANTY OF ANY KIND, NOT
 * EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY. THE AUTHOR OF THIS
 * SOFTWARE, ASSUMES _NO_ RESPONSIBILITY FOR ANY CONSEQUENCE RESULTING
 * FROM THE USE, MODIFICATION, OR REDISTRIBUTION OF THIS SOFTWARE.
 *
 *  ** End legal things **
 *
 * This class allows you to access Google's web APIs through SOAP, to
 * do things like search Google and get the results
 * programmatically. Described at http://www.google.com/apis/ 
 *
 * You need a Google-provided license key to use these
 * services.
 *
 **/

require_once "SOAP/Client.php";
//error_reporting(E_ALL);
/**
 * PHP/SOAP Interface to the Google API
 *
 **/

class GoogleSoap {

  var $_licenseKey = "";
  var $_googleClient = NULL;
  var $_options = array('namespace' => 'urn:GoogleSearch', 'trace' => 1); 
  var $searchResult;
  var $metaData;

  /**
   * constructor
   *
   **/     
  function GoogleSoap($license_key) 
    {
      
      $this->_licenseKey = $license_key;
      
      $this->_googleClient = 
	new SOAP_Client( "http://api.google.com/search/beta2");

    }

  

  
  /**    
   * Search Google using the SOAP API and return the results.
   *
   * You can use the @start and @maxResults parameters to page through
   * multiple pages of results.  Note that 'maxResults' is currently
   * limited by Google to 10.
   * 
   *  See the API reference for more advanced examples and a full list
   *  of country codes and topics for use in the @restrict parameter,
   *  along with legal values for the @language, @inputencoding, and
   *  @outputencoding parameters.
   *
   * You can download the API documentation
   * http://www.google.com/apis/download.html 
   *   
   **/
  
  function doGoogleSearch($q, $start = 0, $maxResults = 10,
			  $filter = true, $restricst='', 
			  $safeSearch = false, $language = '') 
    {

      $google_params = 
	array(
	      "key"         => $this->_licenseKey,
	      "q"           => $q,
	      "start"       => (int)$start,
	      "maxResults"  => (int)$maxResults,
	      "filter"	    => (bool)$filter,
	      "restrict"    => $restricst,
	      "safeSearch"  => (bool)$safeSearch,
	      "lr"	    => $language,
	      "ie"	    => "utf-8",
	      "oe"	    => "utf-8"
	      );
      //var_dump($google_params);
      

      $result = 
	$this->_googleClient->call("doGoogleSearch", $google_params,
				   $this->_options);
      //print $this->_googleClient->__get_wire();
      
      if (!PEAR::isError($result)) 
	{
	  /* Clean out our previous search results */
	  unset($this->searchResult,$this->metaData);
	  foreach ($result->resultElements as $val)
	    {	
	      $this->searchResult[] = get_object_vars($val);
	    }
	  $this->metaData["directoryCategories"] = $result->directoryCategories;
	  $this->metaData["endIndex"] = $result->endIndex;
	  $this->metaData["estimateIsExact"] = $result->estimateIsExact;
	  $this->metaData["estimatedTotalResultsCount"] = $result->estimatedTotalResultsCount;
	  $this->metaData["searchComments"] = $result->searchComments;
	  $this->metaData["searchQuery"] = $result->searchQuery;
	  $this->metaData["searchTime"] = $result->searchTime;
	  $this->metaData["searchTips"] = $result->searchTips;
	  $this->metaData["startIndex"] = $result->startIndex;

	} 
      else
	{
	  echo "\n The follwoing error occured ".$result->getMessage();
	  return false;
	}    
	      
	      
    }

  /**
   * Retrieve a page from the Google cache.
   *
   **/

  function doGetCachedPage( $url)
    {
      $google_params = 
	array( "key"	=> $this->_licenseKey,
	       "url"	=> $url );
      $result = $this->_googleClient->call("doGetCachedPage", $google_params,
				 $this->_options );
      
      if (!PEAR::isError($result)) 
	{
	  return base64_decode($result);
	}
      else
	{
	  echo "\n The following error occured".$this->_googleClient->getMessage();
	  return false;
	}

    }  
 
  
  /**
   * Get spelling suggestions from Google
   *
   */

  function doSpellingSuggestion($phrase)
    {
      
      $google_params = 
	array( "key"	=> $this->_licenseKey,
	       "phrase"	=> $phrase );
      $result = $this->_googleClient->call("doSpellingSuggestion", $google_params,  $this->_options );
      
      if (!PEAR::isError($result)) 
	{
	  return $result;
	}
      else
	{
	  echo "\n The following error occured".$this->_googleClient->getMessage();
	  return false;
	}
      
    }


}

//EOF
?>